.github
.gitignore
CODE_OF_CONDUCT.md
CONTRIBUTING.md
LICENSE
README.markdown
SECURITY.md
archives
bundled-libs
checksums.inc.php
comment.php
composer.json
composer.lock
composer.phar
deployment
docs
exit.php
htmlarea
include
index.php
lang
plugins
rss.php
serendipity.css.php
serendipity_admin.php
serendipity_admin_image_selector.php
serendipity_config.inc.php
serendipity_xmlrpc.php
sql
templates
templates_c
uploads
wfwcomment.php
.htaccess
serendipity_config_local.inc.php