<?php
	/*
	  Serendipity configuration file
	  Written on [[reg_date]]
	*/

	$serendipity['versionInstalled']  = '2.6.0';
	$serendipity['dbName']            = '[[softdb]]';
	$serendipity['dbPrefix']          = '[[dbprefix]]';
	$serendipity['dbHost']            = '[[softdbhost]]';
	$serendipity['dbUser']            = '[[softdbuser]]';
	$serendipity['dbPass']            = '[[softdbpass]]';
	$serendipity['dbType']            = 'mysqli';
	$serendipity['dbPersistent']      = false;
	$serendipity['dbCharset']         = 'utf8';

	// End of Serendipity configuration file
	// You can place your own special variables here; see

	// <https://docs.s9y.org/docs/developers/code-primer.html#docs-initializing-the-framework-serendipity_configincphp-and-serendipity_config_localincphp>

	// for a list. All defaults from serendipity_config.inc.php

	// can be changed by re-setting the variables after here:

?>